/*
 * Generate a VGA signal using a PIC32 microcontroller.
 *
 * Copyright (C) 2017, 2018 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __VGA_H__
#define __VGA_H__

#include "vga_common.h"

#define LINE_LENGTH             92  /* pixels */
#define LINE_COUNT              128 /* display lines per frame */
#define FRAME_COUNT             1   /* double-buffered display */

/* 24MHz cycle measurements. */

#define HFREQ_LIMIT             643
#define HSYNC_START             508
#define HSYNC_LIMIT             40
#define HSYNC_END               (HSYNC_START + HSYNC_LIMIT)

/* Framebuffer properties. */

#define SCREEN_SIZE             (LINE_LENGTH * LINE_COUNT)

/* A frame has an entire screen plus one line to allow horizontal scrolling,
   since a horizontal scroll offset causes the final transfer line to exceed the
   screen limit. */

#define FRAME_SIZE              (SCREEN_SIZE + LINE_LENGTH)

/* Transfer and pixel allocation properties. */

#define TRANSFER_CELL_SIZE      1
#define CELL_SIZE               1

#endif /* __VGA_H__ */
